      SUBROUTINE FAST2(SC,LSR,LM,CFC,ALP,WEIGHT)
C 
C     * JUL 14/92 - E. CHAN (ADD REAL*8 DECLARATIONS)
C     * APR  1/80 - J.D.HENDERSON 
C     * CONTRIBUTION OF COMPLEX FOURIER COEFF IN CFC
C     * TO LATITUDE INTEGRAL ADDED TO SPHERICAL HARMONICS IN SC.
C     * SPECTRAL HARMONICS MUST BE GLOBAL.
C 
C     * LSR(1,M)=START OF ROW M OF SC 
C     * LSR(2,M)=START OF ROW M OF ALP
C                LONGEST ROW LENGTH PERMITTED IS 60.
C     * LM = NUMBER OF ROWS IN SC,ALP ARRAYS. 
C     * ALP = ASSOCIATED LEGENDRE POLYNOMIALS FOR GIVEN LATITUDE. 
C     * WEIGHT = GAUSSIAN WEIGHT FOR GIVEN LATITUDE.
C 
C     * LEVEL 2,SC,CFC,ALP
      IMPLICIT REAL (A-H,O-Z),
     +INTEGER (I-N)
      COMPLEX SC(1),CFC(1)
      REAL*8 ALP(1),WEIGHT
      INTEGER LSR(2,1)
C 
      DO 220 M=1,LM 
      NA=LSR(2,M)-1 
      NL=LSR(1,M) 
      NR=LSR(1,M+1)-1 
      CFCR= REAL(CFC(M))*WEIGHT 
      CFCI= IMAG(CFC(M))*WEIGHT 
C 
      DO 220 N=NL,NR
      NA=NA+1 
  220 SC(N)=SC(N)+CMPLX(CFCR*ALP(NA),CFCI*ALP(NA))
C 
      RETURN
      END 
